/*******************************************************************************
 *	Da8150_lib.h		DA8150 definititions
 *				T.Barnaby,	BEAM Ltd,	2007-01-16
 *******************************************************************************
 * Copyright (c) 2007 BEAM Ltd. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * This is a Linux driver and API library for the Chase Scientific Company's
 * DA8150 8-Chan, 12-Bit, 150 MHz (MS/sec) Arbitrary Waveform Generator PCI board.
 */
#ifndef _DA8150_LIB_H
#define _DA8150_LIB_H

#include <stdint.h>

typedef uint32_t	DWORD;
typedef uint16_t	WORD;
typedef uint8_t		BYTE;
typedef void*		PVOID;
typedef void*		HANDLE;
typedef void*		P9050_HANDLE;
typedef P9050_HANDLE	P9050HANDLE;

#define DA8150_ERROR_NOCARD		1
#define DA8150_ERROR_CARDNUM		6
#define DA8150_ERROR_CARDNOTOPEN	5
#define DA8150_ERROR_MISC		-1

#define D8150_MODE_OFF		0		// Board is disabled
#define D8150_MODE_RUN		1		// Board is set to run
#define D8150_MODE_TRIGRUN	2		// Board is set to run on trigger

#define D8150_TRIG_POS		0		// Positive edge trigger
#define D8150_TRIG_NEG		1		// Negative edge trigger

typedef struct {
	uint32_t	segmentNum;	// Current Segment Number
	uint16_t*	data;		// Pointer to current user segment
					// elements of one diminsional array must be of type uint16_t
	uint32_t	numPoints;	// Number of points in segment (must be even multiple of 64)
	uint32_t	numLoops;	// Number of times to repeat segment (applies to next segment)
	uint32_t	beginPadValue;	// Pad value for beginning of triggered segment
	uint32_t	endPadValue;	// Pad value for end of triggered segment
	uint32_t	trigEnable;	// If > 0 then wait for trigger before going to next segment.
	uint32_t	nextSegNum;	// Next segment to jump to after completion of current segment activities
} Da8150Segment;

DWORD da8150_CountCards(void);
DWORD da8150_Open(DWORD CardNum);
DWORD da8150_Close(DWORD CardNum);

void da8150_SetClock(DWORD CardNum, DWORD Frequency);

void da8150_SetTriggerMode(DWORD CardNum, BYTE Mode, BYTE ExtPol);
void da8150_SetSoftTrigger(DWORD CardNum);
void da8150_SetMarkers(DWORD CardNum, DWORD PointAddr, BYTE Nib1, BYTE Nib2);
void da8150_SetOffset(DWORD CardNum, DWORD ChanNum, int Mode, int Offset);

void da8150_CleanSingleSegmentArea(DWORD CardNum, DWORD NumPointsPerChan);
void da8150_CreateSingleSegment(DWORD CardNum, DWORD ChanNum, DWORD NumPoints, DWORD NumLoops, PVOID UserArrayPtr, DWORD TrigEn);

void da8150_CreateSegments(DWORD CardNum, DWORD ChanNum, DWORD NumSegments, PVOID PtrToSegmentsList);
void da8150_UpdateSegmentCmds(DWORD CardNum, DWORD ChanNum, DWORD NumSegments, PVOID PtrToSegmentsList);

void da8150_Set_Atten(DWORD CardNum, DWORD ChanNum, DWORD Atten_Value);


/*******************************************************************************
 *	P9050 interface code
 *******************************************************************************
 */
#define P9050_OPEN_FIX_BIT7	0

typedef enum
{
    P9050_ADDR_REG     = 0,
    P9050_ADDR_REG_IO  = 1,
    P9050_ADDR_SPACE0  = 2,
    P9050_ADDR_SPACE1  = 3,
    P9050_ADDR_SPACE2  = 4,
    P9050_ADDR_SPACE3  = 5,
    P9050_ADDR_EPROM   = 6,
} P9050_ADDR;

typedef enum
{
    P9050_MODE_BYTE   = 0,
    P9050_MODE_WORD   = 1,
    P9050_MODE_DWORD  = 2
} P9050_MODE;


int P9050_CountCards(void);
int P9050_Open (P9050_HANDLE *phPlx, DWORD dwVendorID, DWORD dwDeviceID, DWORD nCardNum, DWORD options);
int P9050_WriteSpaceWord (P9050_HANDLE hPlx, P9050_ADDR addrSpace, DWORD dwOffset, WORD data);
WORD P9050_ReadSpaceWord (P9050_HANDLE hPlx, P9050_ADDR addrSpace, DWORD dwOffset);
void P9050_Close (P9050_HANDLE hPlx);

#endif


